#[non_exhaustive]pub enum Scope {
Show 85 variants
AnalyticsReadExtensions,
AnalyticsReadGames,
BitsRead,
ChannelBot,
ChannelEditCommercial,
ChannelManageAds,
ChannelManageBroadcast,
ChannelManageClips,
ChannelManageExtensions,
ChannelManageGuestStar,
ChannelManageModerators,
ChannelManagePolls,
ChannelManagePredictions,
ChannelManageRaids,
ChannelManageRedemptions,
ChannelManageSchedule,
ChannelManageVideos,
ChannelManageVips,
ChannelModerate,
ChannelReadAds,
ChannelReadCharity,
ChannelReadEditors,
ChannelReadGoals,
ChannelReadGuestStar,
ChannelReadHypeTrain,
ChannelReadPolls,
ChannelReadPredictions,
ChannelReadRedemptions,
ChannelReadStreamKey,
ChannelReadSubscriptions,
ChannelReadVips,
ChatEdit,
ChatRead,
ClipsEdit,
EditorManageClips,
ModerationRead,
ModeratorManageAnnouncements,
ModeratorManageAutoMod,
ModeratorManageAutomodSettings,
ModeratorManageBannedUsers,
ModeratorManageBlockedTerms,
ModeratorManageChatMessages,
ModeratorManageChatSettings,
ModeratorManageGuestStar,
ModeratorManageShieldMode,
ModeratorManageShoutouts,
ModeratorManageSuspiciousUsers,
ModeratorManageUnbanRequests,
ModeratorManageWarnings,
ModeratorReadAutomodSettings,
ModeratorReadBannedUsers,
ModeratorReadBlockedTerms,
ModeratorReadChatMessages,
ModeratorReadChatSettings,
ModeratorReadChatters,
ModeratorReadFollowers,
ModeratorReadGuestStar,
ModeratorReadModerators,
ModeratorReadShieldMode,
ModeratorReadShoutouts,
ModeratorReadSuspiciousUsers,
ModeratorReadUnbanRequests,
ModeratorReadVips,
ModeratorReadWarnings,
UserBot,
UserEdit,
UserEditBroadcast,
UserManageBlockedUsers,
UserManageChatColor,
UserManageWhispers,
UserReadBlockedUsers,
UserReadBroadcast,
UserReadChat,
UserReadEmail,
UserReadEmotes,
UserReadFollows,
UserReadModeratedChannels,
UserReadSubscriptions,
UserReadWhispers,
UserWriteChat,
WhispersRead,
ChannelSubscriptions,
UserEditFollows,
WhispersEdit,
Other(Cow<'static, str>),
}Expand description
Scopes for twitch.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AnalyticsReadExtensions
View analytics data for the Twitch Extensions owned by the authenticated account.
analytics:read:extensions
AnalyticsReadGames
View analytics data for the games owned by the authenticated account.
analytics:read:games
BitsRead
View Bits information for a channel.
bits:read
ChannelBot
Joins your channel’s chatroom as a bot user, and perform chat-related actions as that user.
channel:bot
ChannelEditCommercial
Run commercials on a channel.
channel:edit:commercial
ChannelManageAds
Manage ads schedule on a channel.
channel:manage:ads
ChannelManageBroadcast
Manage a channel’s broadcast configuration, including updating channel configuration and managing stream markers and stream tags.
channel:manage:broadcast
ChannelManageClips
Manage Clips for a channel.
channel:manage:clips
ChannelManageExtensions
Manage a channel’s Extension configuration, including activating Extensions.
channel:manage:extensions
ChannelManageGuestStar
Manage Guest Star for your channel.
channel:manage:guest_star
ChannelManageModerators
Add or remove the moderator role from users in your channel.
channel:manage:moderators
ChannelManagePolls
Manage a channel’s polls.
channel:manage:polls
ChannelManagePredictions
Manage of channel’s Channel Points Predictions
channel:manage:predictions
ChannelManageRaids
Manage a channel raiding another channel.
channel:manage:raids
ChannelManageRedemptions
Manage Channel Points custom rewards and their redemptions on a channel.
channel:manage:redemptions
ChannelManageSchedule
Manage a channel’s stream schedule.
channel:manage:schedule
ChannelManageVideos
Manage a channel’s videos, including deleting videos.
channel:manage:videos
ChannelManageVips
Add or remove the VIP role from users in your channel.
channel:manage:vips
ChannelModerate
Perform moderation actions in a channel.
channel:moderate
ChannelReadAds
Read the ads schedule and details on your channel.
channel:read:ads
ChannelReadCharity
Read charity campaign details and user donations on your channel.
channel:read:charity
ChannelReadEditors
View a list of users with the editor role for a channel.
channel:read:editors
ChannelReadGoals
View Creator Goals for a channel.
channel:read:goals
ChannelReadGuestStar
Read Guest Star details for your channel.
channel:read:guest_star
ChannelReadHypeTrain
View Hype Train information for a channel.
channel:read:hype_train
ChannelReadPolls
View a channel’s polls.
channel:read:polls
ChannelReadPredictions
View a channel’s Channel Points Predictions.
channel:read:predictions
ChannelReadRedemptions
View Channel Points custom rewards and their redemptions on a channel.
channel:read:redemptions
ChannelReadStreamKey
View an authorized user’s stream key.
channel:read:stream_key
ChannelReadSubscriptions
View a list of all subscribers to a channel and check if a user is subscribed to a channel.
channel:read:subscriptions
ChannelReadVips
Read the list of VIPs in your channel.
channel:read:vips
ChatEdit
Send chat messages to a chatroom using an IRC connection.
chat:edit
ChatRead
View chat messages sent in a chatroom using an IRC connection.
chat:read
ClipsEdit
Manage Clips for a channel.
clips:edit
EditorManageClips
Manage Clips as an editor.
editor:manage:clips
ModerationRead
View a channel’s moderation data including Moderators, Bans, Timeouts, and Automod settings.
moderation:read
ModeratorManageAnnouncements
Send announcements in channels where you have the moderator role.
moderator:manage:announcements
ModeratorManageAutoMod
Manage messages held for review by AutoMod in channels where you are a moderator.
moderator:manage:automod
ModeratorManageAutomodSettings
Manage a broadcaster’s AutoMod settings.
moderator:manage:automod_settings
ModeratorManageBannedUsers
Ban and unban users.
moderator:manage:banned_users
ModeratorManageBlockedTerms
Manage a broadcaster’s list of blocked terms.
moderator:manage:blocked_terms
ModeratorManageChatMessages
Delete chat messages in channels where you have the moderator role
moderator:manage:chat_messages
ModeratorManageChatSettings
Manage a broadcaster’s chat room settings.
moderator:manage:chat_settings
ModeratorManageGuestStar
Manage Guest Star for channels where you are a Guest Star moderator.
moderator:manage:guest_star
ModeratorManageShieldMode
Manage a broadcaster’s Shield Mode status.
moderator:manage:shield_mode
ModeratorManageShoutouts
Manage a broadcaster’s shoutouts.
moderator:manage:shoutouts
ModeratorManageSuspiciousUsers
Manage suspicious user statuses in channels where the user has the moderator role.
moderator:manage:suspicious_users
ModeratorManageUnbanRequests
Manage a broadcaster’s unban requests.
moderator:manage:unban_requests
ModeratorManageWarnings
Warn users in channels where you have the moderator role.
moderator:manage:warnings
ModeratorReadAutomodSettings
View a broadcaster’s AutoMod settings.
moderator:read:automod_settings
ModeratorReadBannedUsers
Read the list of bans or unbans in channels where you have the moderator role.
moderator:read:banned_users
ModeratorReadBlockedTerms
View a broadcaster’s list of blocked terms.
moderator:read:blocked_terms
ModeratorReadChatMessages
Read deleted chat messages in channels where you have the moderator role.
moderator:read:chat_messages
ModeratorReadChatSettings
View a broadcaster’s chat room settings.
moderator:read:chat_settings
ModeratorReadChatters
View the chatters in a broadcaster’s chat room.
moderator:read:chatters
ModeratorReadFollowers
Read the followers of a broadcaster.
moderator:read:followers
ModeratorReadGuestStar
Read Guest Star details for channels where you are a Guest Star moderator.
moderator:read:guest_star
ModeratorReadModerators
Read the list of moderators in channels where you have the moderator role.
moderator:read:moderators
ModeratorReadShieldMode
View a broadcaster’s Shield Mode status.
moderator:read:shield_mode
ModeratorReadShoutouts
View a broadcaster’s shoutouts.
moderator:read:shoutouts
ModeratorReadSuspiciousUsers
Read chat messages from suspicious users and see users flagged as suspicious in channels where the user has the moderator role.
moderator:read:suspicious_users
ModeratorReadUnbanRequests
View a broadcaster’s unban requests.
moderator:read:unban_requests
ModeratorReadVips
Read the list of VIPs in channels where you have the moderator role.
moderator:read:vips
ModeratorReadWarnings
Read warnings in channels where you have the moderator role.
moderator:read:warnings
UserBot
Join a specified chat channel as your user and appear as a bot, and perform chat-related actions as your user.
user:bot
UserEdit
Manage a user object.
user:edit
UserEditBroadcast
View and edit a user’s broadcasting configuration, including Extension configurations.
user:edit:broadcast
UserManageBlockedUsers
Manage the block list of a user.
user:manage:blocked_users
UserManageChatColor
Update the color used for the user’s name in chat.
user:manage:chat_color
UserManageWhispers
Receive whispers sent to your user, and send whispers on your user’s behalf.
user:manage:whispers
UserReadBlockedUsers
View the block list of a user.
user:read:blocked_users
UserReadBroadcast
View a user’s broadcasting configuration, including Extension configurations.
user:read:broadcast
UserReadChat
Receive chatroom messages and informational notifications relating to a channel’s chatroom.
user:read:chat
UserReadEmail
View a user’s email address.
user:read:email
UserReadEmotes
View emotes available to a user
user:read:emotes
UserReadFollows
View the list of channels a user follows.
user:read:follows
UserReadModeratedChannels
Read the list of channels you have moderator privileges in.
user:read:moderated_channels
UserReadSubscriptions
View if an authorized user is subscribed to specific channels.
user:read:subscriptions
UserReadWhispers
Receive whispers sent to your user.
user:read:whispers
UserWriteChat
Send chat messages to a chatroom.
user:write:chat
WhispersRead
Receive whisper messages for your user using PubSub.
whispers:read
ChannelSubscriptions
Use ChannelReadSubscriptions (channel:read:subscriptions) instead
Read all subscribers to your channel.
channel_subscriptions
UserEditFollows
Not used anymore, see https://discuss.dev.twitch.tv/t/deprecation-of-create-and-delete-follows-api-endpoints/32351
[DEPRECATED] Was previously used for “Create User Follows” and “Delete User Follows.
user:edit:follows
WhispersEdit
Use UserManageWhispers (user:manage:whispers) instead
[DEPRECATED] Send whisper messages.
whispers:edit
Other(Cow<'static, str>)
Other scope that is not implemented.
Implementations
Sourceimpl Scope
impl Scope
Sourcepub fn all() -> Vec<Scope>
pub fn all() -> Vec<Scope>
Get a vec of all defined twitch Scopes.
Please note that this may not work for you, as some auth flows and “apis” don’t accept all scopes
Sourcepub const fn all_slice() -> &'static [Scope]
pub const fn all_slice() -> &'static [Scope]
Get a slice of all defined twitch Scopes.
Please note that this may not work for you, as some auth flows and “apis” don’t accept all scopes
Sourcepub const fn description(&self) -> &'static str
pub const fn description(&self) -> &'static str
Get a description for the token
Sourcepub const fn as_static_str(&self) -> &'static str
pub const fn as_static_str(&self) -> &'static str
Get the scope as a static string slice.
Panics
This function panics if the scope can’t be represented as a static string slice